@@ -4,7 +4,6 @@ import xml.etree.ElementTree as ET
 
 import requests
 
-from prtg.icon import Icon
 from prtg.exception import DuplicateObject, ObjectNotFound, Unauthorized
 
 class PrtgApi:
@@ -32,13 +31,15 @@ class PrtgApi:
             password, 
             template_group = None, 
             template_device = None, 
-            is_passhash = False):
+            is_passhash = False,
+            requests_verify = True):
         self.url = url
         self.username = username
         self.password = password
         self.template_group = template_group
         self.template_device = template_device
         self.is_passhash = is_passhash
+        self.requests_verify = requests_verify
         self._validate_cred()
     
     def _requests_get(self, endpoint, params=None):
@@ -62,7 +63,7 @@ class PrtgApi:
         auth = {'username': self.username, key: self.password}
         if params:
             auth.update(params)
-        response = requests.get(url, auth)
+        response = requests.get(url, auth, verify=self.requests_verify)
         try:
             response.raise_for_status()
         except requests.HTTPError as e:
@@ -106,6 +107,7 @@ class PrtgApi:
         return f'{self.url}/device.htm?id={id}'
 
     # Sensortree
+
     def get_sensortree(self, group_id=None):
         """Get sensortree
 
@@ -324,12 +326,20 @@ class PrtgApi:
             group_id (Union[int, str]): id of parent group
 
         Returns:
-            list[dict]: all devices and their details
+            list[dict]: devices and their details
         """
         params = {'id': group_id}
         return self._get_devices_base(params)
 
     def get_devices_by_name_containing(self, name):
+        """Get devices by partial or full name
+
+        Args:
+            name (str): partial or full name
+
+        Returns:
+            list[dict]: devices and their details
+        """
         params = {'filter_name': f'@sub({name})'}
         return self._get_devices_base(params)
 
@@ -540,8 +550,100 @@ class PrtgApi:
         """
         self._set_obj_property_base(id, 'locationgroup_', 1)
 
+    # Sensors
+
+    def _get_sensors_base(self, extra=None):
+        """Base function for returning sensors
+
+        Args:
+            extra (dict): additional parameters to filter sensors. Defaults to 
+                None.
+
+        Returns:
+            list[dict]: sensors and their details
+        """
+        endpoint = '/api/table.json'
+        params = {
+            'content': 'sensors',
+            'columns': 'objid,probe,group,device,status,priority,active,name'
+        }
+        if extra:
+            params.update(extra)
+        response = self._requests_get(endpoint, params)
+        return response.json()['sensors']
+        
+    def get_sensors_by_name(self, name, group=None, device=None):
+        """Get sensors by name
+
+        Args:
+            name (str): name of sensor
+            group (str, optional): name of group to filter by. Defaults to None.
+            device (str, optional): name of device to filter by. Defaults to None.
+
+        Returns:
+            list[dict]: sensors and their details
+        """
+        params = {
+            'filter_name': name,
+            'filter_device': device
+        }
+        if group:
+            params['filter_group']= f'@sub({group})'
+        return self._get_sensors_base(params)
+
+    def get_sensors_by_name_containing(self, name, group=None, device=None):
+        """Get sensors by partial or full name
+
+        Args:
+            name (str): partial or full name of sensor
+            group (str, optional): name of group to filter by. Defaults to None.
+            device (str, optional): name of device to filter by. Defaults to None.
+
+        Returns:
+            list[dict]: sensors and their details
+        """
+        params = {
+            'filter_name': f'@sub({name})',
+            'filter_device': device
+        }
+        if group:
+            params['filter_group']= f'@sub({group})'
+        return self._get_sensors_base(params)
+
+    def get_sensor(self, id):
+        """Get one sensor by id
+
+        Args:
+            id (Union[int, str]): id of sensor
+
+        Raises:
+            ObjectNotFound: when no sensor is found
+
+        Returns:
+            dict: sensor details
+        """
+        params = {'filter_objid': id}
+        try:
+            return self._get_sensors_base(params)[0]
+        except IndexError:
+            raise ObjectNotFound('No sensor with matching ID.')
+
     # Actions
 
+    def move_object(self, id, group_id):
+        """Move object to new group
+
+        Args:
+            id (Union[int, str]): id of object
+            group_id (Union[int, str]): id of target group
+        """
+        endpoint = '/moveobjectnow.htm'
+        params = {
+            'id': id,
+            'targetid': group_id
+        }
+        self._requests_get(endpoint, params)
+
     def pause_object(self, id):
         """Pause object
 
